# Pemuda Persis Bot

A dedicated chatbot for Pemuda Persis Digital Media.

### Telegram Account : 

- Production : t.me/pemudapersis_bot
- Development : t.me/pemudapersisdev_bot

Please contact @zamzambadruzaman for the bot token.
